@@ -140,7 +140,7 @@ setMethod("bplapply", c("ANY", "SerialParam"),
             result[[i]] <- value
         } else {
             if (length(result))
-                result[[1]] <- REDUCE(result[[1]], unlist(value))
+                result[[1]] <- REDUCE(result[[1]], value)
             else
                 result[[1]] <- value 
         }
